@@ -10,20 +10,20 @@ import time
 
 
 class ConfuseCallback(tf.keras.callbacks.Callback):
-    def __init__(self, x_test, y_test, file_writer, class_names=None, y_argmax=False, figure_size=(12, 10)):
+    def __init__(self, x_test, y_test, file_writer, class_names=None, figure_size=(12, 10)):
         super(ConfuseCallback, self).__init__()
         self.x_test = x_test
-        self.y_test = y_test
+        self.y_test = y_test if len(y_test.shape) == 1 else np.argmax(y_test, axis=1)
         self.file_writer = file_writer
         self.figure_size = figure_size
-        self.class_names = class_names
+        self.label_names = class_names
 
-        if self.class_names is None:
-            self.class_names = ["Class {:02d}".format(unique_label) for unique_label in np.unique(np.argmax(y_test, axis=1) if y_argmax else y_test)]
+        if self.label_names is None:
+            self.label_names = ["Class {:02d}".format(unique_label) for unique_label in np.unique(self.y_test)]
 
     def get_precision_recall_plot(self, con_mat):
-        precisions = np.array([0] * len(self.class_names)).astype('float32')
-        recalls = np.array([0] * len(self.class_names)).astype('float32')
+        precisions = np.array([0] * len(self.label_names)).astype('float32')
+        recalls = np.array([0] * len(self.label_names)).astype('float32')
 
         for i in range(con_mat.shape[0]):
             tp = con_mat[i, i]
@@ -40,7 +40,7 @@ class ConfuseCallback(tf.keras.callbacks.Callback):
             precisions[i] = max(0, tp / (tp + fp))
             recalls[i] = max(0, tp / (tp + fn))
 
-        df = pd.DataFrame((self.class_names, precisions, recalls)).T
+        df = pd.DataFrame((self.label_names, precisions, recalls)).T
         df.columns = ["Class", "Precision", "Recall"]
         df = pd.melt(df, id_vars="Class", var_name="Type", value_name="Value")
 
@@ -67,8 +67,8 @@ class ConfuseCallback(tf.keras.callbacks.Callback):
             con_mat_norm = np.around(con_mat.astype('float') / con_mat.sum(axis=1)[:, np.newaxis], decimals=2)
 
             con_mat_df = pd.DataFrame(con_mat_norm,
-                                      index=self.class_names,
-                                      columns=self.class_names)
+                                      index=self.label_names,
+                                      columns=self.label_names)
 
             precision_recall_image, precisions, recalls = self.get_precision_recall_plot(con_mat)
 
@@ -164,7 +164,7 @@ def get_tf_callbacks(root,
         if x_test is not None and y_test is not None:
             callbacks_.append(ConfuseCallback(x_test, y_test,
                                               file_writer,
-                                              class_names=label_info,
+                                              label_names=label_info,
                                               y_argmax=y_argmax,
                                               figure_size=figure_size)
                               )
